# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.api.company_api import CompanyApi


class TestCompanyApi(unittest.TestCase):
    """CompanyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CompanyApi()

    def tearDown(self) -> None:
        pass

    def test_get_company(self) -> None:
        """Test case for get_company

        Retrieve the properties and relationships of an object of type company for Dynamics 365 Business Central.
        """
        pass

    def test_list_companies(self) -> None:
        """Test case for list_companies

        Returns a list of companies
        """
        pass


if __name__ == '__main__':
    unittest.main()
