# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.api.purchase_invoice_api import PurchaseInvoiceApi


class TestPurchaseInvoiceApi(unittest.TestCase):
    """PurchaseInvoiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PurchaseInvoiceApi()

    def tearDown(self) -> None:
        pass

    def test_delete_purchase_invoice(self) -> None:
        """Test case for delete_purchase_invoice

        Deletes an object of type purchaseInvoice in Dynamics 365 Business Central
        """
        pass

    def test_get_purchase_invoice(self) -> None:
        """Test case for get_purchase_invoice

        Retrieve the properties and relationships of an object of type purchaseInvoice for Dynamics 365 Business Central.
        """
        pass

    def test_list_purchase_invoices(self) -> None:
        """Test case for list_purchase_invoices

        Returns a list of purchaseInvoices
        """
        pass

    def test_patch_purchase_invoice(self) -> None:
        """Test case for patch_purchase_invoice

        Updates an object of type purchaseInvoice in Dynamics 365 Business Central
        """
        pass

    def test_post_purchase_invoice(self) -> None:
        """Test case for post_purchase_invoice

        Creates an object of type purchaseInvoice in Dynamics 365 Business Central
        """
        pass


if __name__ == '__main__':
    unittest.main()
