# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.itemunitofmeasureconversiontype import Itemunitofmeasureconversiontype

class TestItemunitofmeasureconversiontype(unittest.TestCase):
    """Itemunitofmeasureconversiontype unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Itemunitofmeasureconversiontype:
        """Test Itemunitofmeasureconversiontype
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Itemunitofmeasureconversiontype`
        """
        model = Itemunitofmeasureconversiontype()
        if include_optional:
            return Itemunitofmeasureconversiontype(
                to_unit_of_measure = '',
                from_to_conversion_rate = 1.337,
                picture = [
                    pybusinesscentral.model.picture.picture(
                        id = '', 
                        width = 56, 
                        height = 56, 
                        content_type = '', 
                        content@odata/media_edit_link = '', 
                        content@odata/media_read_link = '', )
                    ],
                default_dimensions = [
                    pybusinesscentral.model.default_dimensions.defaultDimensions(
                        parent_id = '', 
                        dimension_id = '', 
                        dimension_code = '', 
                        dimension_value_id = '', 
                        dimension_value_code = '', 
                        posting_validation = '', 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        dimension = pybusinesscentral.model.dimension.dimension(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            dimension_values = [
                                pybusinesscentral.model.dimension_value.dimensionValue(
                                    id = '', 
                                    code = '', 
                                    display_name = '', 
                                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                                ], ), 
                        dimension_value = pybusinesscentral.model.dimension_value.dimensionValue(
                            id = '', 
                            code = '', 
                            display_name = '', 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                item_category = pybusinesscentral.model.item_category.itemCategory(
                    id = '', 
                    code = '', 
                    display_name = '', 
                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return Itemunitofmeasureconversiontype(
        )
        """

    def testItemunitofmeasureconversiontype(self):
        """Test Itemunitofmeasureconversiontype"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
