# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.api.dimension_set_line_api import DimensionSetLineApi


class TestDimensionSetLineApi(unittest.TestCase):
    """DimensionSetLineApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DimensionSetLineApi()

    def tearDown(self) -> None:
        pass

    def test_get_dimension_set_lines_for_sales_invoice_line(self) -> None:
        """Test case for get_dimension_set_lines_for_sales_invoice_line

        Retrieve the properties and relationships of the list of dimensionSetLines for a salesInvoiceLine.
        """
        pass

    def test_post_dimension_set_line(self) -> None:
        """Test case for post_dimension_set_line

        Creates an object of type dimensionSetLine in Dynamics 365 Business Central
        """
        pass


if __name__ == '__main__':
    unittest.main()
