# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.list_dimensions200_response import ListDimensions200Response

class TestListDimensions200Response(unittest.TestCase):
    """ListDimensions200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListDimensions200Response:
        """Test ListDimensions200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListDimensions200Response`
        """
        model = ListDimensions200Response()
        if include_optional:
            return ListDimensions200Response(
                value = [
                    pybusinesscentral.model.dimension.dimension(
                        id = '', 
                        code = '', 
                        display_name = '', 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        dimension_values = [
                            pybusinesscentral.model.dimension_value.dimensionValue(
                                id = '', 
                                code = '', 
                                display_name = '', 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], )
                    ]
            )
        else:
            return ListDimensions200Response(
        )
        """

    def testListDimensions200Response(self):
        """Test ListDimensions200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
