# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.general_ledger_entry_attachments import GeneralLedgerEntryAttachments

class TestGeneralLedgerEntryAttachments(unittest.TestCase):
    """GeneralLedgerEntryAttachments unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GeneralLedgerEntryAttachments:
        """Test GeneralLedgerEntryAttachments
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GeneralLedgerEntryAttachments`
        """
        model = GeneralLedgerEntryAttachments()
        if include_optional:
            return GeneralLedgerEntryAttachments(
                general_ledger_entry_number = 56,
                id = '',
                file_name = '',
                byte_size = 56,
                content = bytes(b'blah'),
                created_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                general_ledger_entry = pybusinesscentral.model.general_ledger_entry.generalLedgerEntry(
                    id = 56, 
                    posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    document_number = '', 
                    document_type = '', 
                    account_id = '', 
                    account_number = '', 
                    description = '', 
                    debit_amount = 1.337, 
                    credit_amount = 1.337, 
                    dimensions = [
                        null
                        ], 
                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    account = pybusinesscentral.model.account.account(
                        id = '', 
                        number = '', 
                        display_name = '', 
                        category = '', 
                        sub_category = '', 
                        blocked = True, 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
            )
        else:
            return GeneralLedgerEntryAttachments(
        )
        """

    def testGeneralLedgerEntryAttachments(self):
        """Test GeneralLedgerEntryAttachments"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
