# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.picture import Picture

class TestPicture(unittest.TestCase):
    """Picture unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Picture:
        """Test Picture
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Picture`
        """
        model = Picture()
        if include_optional:
            return Picture(
                id = '',
                width = 56,
                height = 56,
                content_type = '',
                contentodata_media_edit_link = '',
                contentodata_media_read_link = ''
            )
        else:
            return Picture(
        )
        """

    def testPicture(self):
        """Test Picture"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
