# coding: utf-8

"""
    (v2.0) Dynamics 365 Business Central

    (v2.0) Business Central Standard APIs

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pybusinesscentral.model.journal import Journal

class TestJournal(unittest.TestCase):
    """Journal unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Journal:
        """Test Journal
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Journal`
        """
        model = Journal()
        if include_optional:
            return Journal(
                id = '',
                code = '',
                display_name = '',
                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                balancing_account_id = '',
                balancing_account_number = '',
                journal_lines = [
                    pybusinesscentral.model.journal_line.journalLine(
                        id = '', 
                        journal_display_name = '', 
                        line_number = 56, 
                        account_type = '', 
                        account_id = '', 
                        account_number = '', 
                        posting_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        document_number = '', 
                        external_document_number = '', 
                        amount = 1.337, 
                        description = '', 
                        comment = '', 
                        dimensions = [
                            null
                            ], 
                        last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        attachments = [
                            pybusinesscentral.model.attachments.attachments(
                                parent_id = '', 
                                id = '', 
                                file_name = '', 
                                byte_size = 56, 
                                content = bytes(b'blah'), 
                                last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        account = pybusinesscentral.model.account.account(
                            id = '', 
                            number = '', 
                            display_name = '', 
                            category = '', 
                            sub_category = '', 
                            blocked = True, 
                            last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), )
                    ],
                account = pybusinesscentral.model.account.account(
                    id = '', 
                    number = '', 
                    display_name = '', 
                    category = '', 
                    sub_category = '', 
                    blocked = True, 
                    last_modified_date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
            )
        else:
            return Journal(
        )
        """

    def testJournal(self):
        """Test Journal"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
